==> owncloud-9.0.0.tar.bz2: owncloud/apps/files/l10n/de_DE.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Speicher nicht verfügbar",
    "Storage invalid" : "Speicher ungültig",
    "Unknown error" : "Unbekannter Fehler",
    "Unable to set upload directory." : "Das Upload-Verzeichnis konnte nicht gesetzt werden.",
    "Invalid Token" : "Ungültiger Token",
    "No file was uploaded. Unknown error" : "Keine Datei hochgeladen. Unbekannter Fehler",
    "There is no error, the file uploaded with success" : "Es ist kein Fehler aufgetreten. Die Datei wurde erfolgreich hochgeladen.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Die hochgeladene Datei überschreitet die upload_max_filesize-Vorgabe in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die Datei ist größer, als die MAX_FILE_SIZE-Vorgabe erlaubt, die im HTML-Formular spezifiziert ist",
    "The uploaded file was only partially uploaded" : "Die Datei konnte nur teilweise übertragen werden",
    "No file was uploaded" : "Es wurde keine Datei hochgeladen",
    "Missing a temporary folder" : "Kein temporärer Ordner vorhanden",
    "Failed to write to disk" : "Fehler beim Schreiben auf die Festplatte",
    "Not enough storage available" : "Nicht genug Speicher vorhanden.",
    "The target folder has been moved or deleted." : "Der Zielordner wurde verschoben oder gelöscht.",
    "Upload failed. Could not find uploaded file" : "Hochladen fehlgeschlagen. Die hochgeladene Datei konnte nicht gefunden werden.",
    "Upload failed. Could not get file info." : "Hochladen fehlgeschlagen. Die Dateiinformationen konnten nicht abgerufen werden.",
    "Invalid directory." : "Ungültiges Verzeichnis.",
    "Files" : "Dateien",
    "All files" : "Alle Dateien",
    "Favorites" : "Favoriten",
    "Home" : "Zuhause",
    "Close" : "Schließen",
    "Upload cancelled." : "Upload abgebrochen.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Die Datei {filename} kann nicht hochgeladen werden, da sie entweder ein Verzeichnis oder 0 Bytes groß ist",
    "Total file size {size1} exceeds upload limit {size2}" : "Die Gesamt-Größe {size1} überschreitet die Upload-Begrenzung {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nicht genügend freier Speicherplatz, Sie möchten {size1} hochladen, es sind jedoch nur noch {size2} verfügbar.",
    "Error uploading file \"{fileName}\": {message}" : "Fehler beim Hochladen der Datei \"{fileName}\": {message}",
    "Could not get result from server." : "Ergebnis konnte nicht vom Server abgerufen werden.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Dateiupload läuft. Wenn Sie die Seite jetzt verlassen, wird der Upload abgebrochen.",
    "Actions" : "Aktionen",
    "Download" : "Herunterladen",
    "Rename" : "Umbenennen",
    "Delete" : "Löschen",
    "Disconnect storage" : "Speicher trennen",
    "Unshare" : "Freigabe aufheben",
    "Details" : "Details",
    "Select" : "Auswählen",
    "Pending" : "Ausstehend",
    "Unable to determine date" : "Datum konnte nicht ermittelt werden",
    "This operation is forbidden" : "Diese Operation ist nicht erlaubt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte überprüfen Sie die Logdateien oder kontaktieren Sie den Administrator",
    "Could not move \"{file}\", target exists" : "Die Datei konnte nicht verschoben werden \"{file}\", da die Datei im Zielordner bereits existiert",
    "Could not move \"{file}\"" : "Die Datei konnte nicht verschoben werden \"{file}\"",
    "{newName} already exists" : "{newName} existiert bereits",
    "Could not rename \"{fileName}\", it does not exist any more" : "Die Datei konnte nicht umbennant werden \"{fileName}\", da die Datei nicht mehr existiert",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name „{targetName}“ wird bereits im Ordner „{dir}“ benutzt. Bitte wählen Sie einen anderen Namen.",
    "Could not rename \"{fileName}\"" : "Die Datei konnte nicht umbenannt werden \"{fileName}\"",
    "Could not create file \"{file}\"" : "Die Datei konnte nicht erstellt werden \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Die Datei konnte nicht erstellt werden \"{file}\", da diese bereits existiert",
    "Could not create folder \"{dir}\"" : "Der Ordner konnte nicht erstellt werden \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "Der Ordner konnte nicht erstellt werden \"{dir}\", da dieser bereits existiert",
    "Error deleting file \"{fileName}\"." : "Fehler beim löschen der Datei \"{fileName}\".",
    "No entries in this folder match '{filter}'" : "Keine Einträge in diesem Ordner stimmen mit '{filter}' überein",
    "Name" : "Name",
    "Size" : "Größe",
    "Modified" : "Geändert",
    "_%n folder_::_%n folders_" : ["%n Ordner","%n Ordner"],
    "_%n file_::_%n files_" : ["%n Datei","%n Dateien"],
    "{dirs} and {files}" : "{dirs} und {files}",
    "You don’t have permission to upload or create files here" : "Sie haben keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
    "_Uploading %n file_::_Uploading %n files_" : ["%n Datei wird hoch geladen","%n Dateien werden hoch geladen"],
    "New" : "Neu",
    "\"{name}\" is an invalid file name." : "„{name}“ ist kein gültiger Dateiname.",
    "File name cannot be empty." : "Der Dateiname darf nicht leer sein.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Der Speicher von {owner} ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ihr Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Der Speicher von {owner} ist beinahe voll ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ihr Speicher ist fast voll ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["stimmt mit '{filter}' überein","stimmen mit '{filter}' überein"],
    "Path" : "Pfad",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favorisiert",
    "Favorite" : "Favorit",
    "Folder" : "Ordner",
    "New folder" : "Neuer Ordner",
    "{newname} already exists" : "{newname} existiert bereits",
    "Upload" : "Hochladen",
    "An error occurred while trying to update the tags" : "Es ist ein Fehler beim Aktualisieren der Tags aufgetreten",
    "A new file or folder has been <strong>created</strong>" : "Eine neue Datei oder ein neuer Ordner wurde <strong>erstellt</strong>",
    "A file or folder has been <strong>changed</strong>" : "Eine Datei oder ein Ordner wurde <strong>geändert</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Benachrichtigungen über Neues und Änderungen auf Ihre <strong>favorisierten Dateien</strong> beschränken <em>(nur im Stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Eine Datei oder ein Ordner wurde <strong>gelöscht</strong>",
    "A file or folder has been <strong>restored</strong>" : "Eine Datei oder ein Ordner wurde <strong>wiederhergestellt</strong>",
    "You created %1$s" : "Sie haben %1$s erstellt",
    "%2$s created %1$s" : "%2$s hat %1$s erstellt",
    "%1$s was created in a public folder" : "%1$s wurde in einem öffentlichen Ordner erstellt",
    "You changed %1$s" : "Sie haben %1$s geändert",
    "%2$s changed %1$s" : "%2$s hat %1$s geändert",
    "You deleted %1$s" : "Sie haben %1$s gelöscht",
    "%2$s deleted %1$s" : "%2$s hat %1$s gelöscht",
    "You restored %1$s" : "Sie haben %1$s wiederhergestellt",
    "%2$s restored %1$s" : "%2$s wiederhergestellt %1$s",
    "Changed by %2$s" : "Geändert von %2$s",
    "Deleted by %2$s" : "Gelöscht durch %2$s",
    "Restored by %2$s" : "Wiederhergestellt durch %2$s",
    "Upload (max. %s)" : "Hochladen (max. %s)",
    "File handling" : "Dateibehandlung",
    "Maximum upload size" : "Maximale Upload-Größe",
    "max. possible: " : "maximal möglich:",
    "Save" : "Speichern",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Bei PHP-FPM kann es 5 Minuten dauern, bis Änderungen angewendet sind.",
    "Missing permissions to edit from here." : "Fehlende Berechtigungen um von hier aus zu bearbeiten.",
    "Settings" : "Einstellungen",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Benutzen Sie diese Adresse, um <a href=\"%s\" target=\"_blank\">über WebDAV auf Ihre Dateien zuzugreifen</a>",
    "Cancel upload" : "Upload abbrechen",
    "No files in here" : "Keine Dateien vorhanden",
    "Upload some content or sync with your devices!" : "Laden Sie Inhalte hoch oder synchronisieren Sie mit Ihren Geräten!",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Select all" : "Alle auswählen",
    "Upload too large" : "Der Upload ist zu groß",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Die Datei überschreitet die Maximalgröße für Uploads auf diesem Server.",
    "No favorites" : "Keine Favoriten",
    "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die Sie als Favoriten kennzeichnen, werden hier erscheinen",
    "Text file" : "Textdatei",
    "New text file.txt" : "Neue Textdatei file.txt"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.3.tar.bz2: owncloud/apps/files/l10n/de_DE.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
    "Storage invalid" : "Speicher ungültig",
    "Unknown error" : "Unbekannter Fehler",
    "All files" : "Alle Dateien",
    "Saved" : "Gespeichert",
    "There was an error saving" : "Ein Fehler ist beim Speichern aufgetreten",
    "File could not be found" : "Datei konnte nicht gefunden werden",
    "Home" : "Zuhause",
    "Close" : "Schließen",
    "Favorites" : "Favoriten",
    "Could not create folder \"{dir}\"" : "Der Ordner konnte nicht erstellt werden \"{dir}\"",
    "Upload cancelled." : "Upload abgebrochen.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Die Datei {filename} kann nicht hochgeladen werden, da sie entweder ein Verzeichnis oder 0 Bytes groß ist",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nicht genügend freier Speicherplatz, Sie möchten {size1} hochladen, es sind jedoch nur noch {size2} verfügbar.",
    "Target folder \"{dir}\" does not exist any more" : "Zielverzeichnis \"{dir}\" existiert nicht mehr",
    "Target folder does not exist any more" : "Zielverzeichnis existiert nicht mehr",
    "Not enough free space" : "nicht genug freier Speicher vorhanden",
    "Uploading..." : "Hochladen…",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} von {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Dateiupload läuft. Wenn Sie die Seite jetzt verlassen, wird der Upload abgebrochen.",
    "Actions" : "Aktionen",
    "Download" : "Herunterladen",
    "Rename" : "Umbenennen",
    "Delete" : "Löschen",
    "Disconnect storage" : "Speicher trennen",
    "Unshare" : "Freigabe aufheben",
    "Could not load info for file \"{file}\"" : "Informationen zur Datei \"{file}\" konnten nicht geladen werden",
    "Files" : "Dateien",
    "Details" : "Details",
    "Select" : "Auswählen",
    "Pending" : "Ausstehend",
    "Unable to determine date" : "Datum konnte nicht ermittelt werden",
    "Invalid path" : "Ungültiger Pfad",
    "This operation is forbidden" : "Diese Operation ist nicht erlaubt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte überprüfen Sie die Logdateien oder kontaktieren Sie den Administrator",
    "Could not move \"{file}\", target exists" : "Die Datei konnte nicht verschoben werden \"{file}\", da die Datei im Zielordner bereits existiert",
    "Could not move \"{file}\"" : "Die Datei konnte nicht verschoben werden \"{file}\"",
    "{newName} already exists" : "{newName} existiert bereits",
    "Could not rename \"{fileName}\", it does not exist any more" : "Die Datei konnte nicht umbennant werden \"{fileName}\", da die Datei nicht mehr existiert",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name „{targetName}“ wird bereits im Ordner „{dir}“ benutzt. Bitte wählen Sie einen anderen Namen.",
    "Could not rename \"{fileName}\"" : "Die Datei konnte nicht umbenannt werden \"{fileName}\"",
    "Could not create file \"{file}\"" : "Die Datei konnte nicht erstellt werden \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Die Datei konnte nicht erstellt werden \"{file}\", da diese bereits existiert",
    "Could not create folder \"{dir}\" because it already exists" : "Der Ordner konnte nicht erstellt werden \"{dir}\", da dieser bereits existiert",
    "Error deleting file \"{fileName}\"." : "Fehler beim löschen der Datei \"{fileName}\".",
    "No entries in this folder match {filter}" : "Keine Einträge in diesem Ordner stimmen mit {filter} überein",
    "Name" : "Name",
    "Size" : "Größe",
    "Modified" : "Geändert",
    "_%n folder_::_%n folders_" : ["%n Ordner","%n Ordner"],
    "_%n file_::_%n files_" : ["%n Datei","%n Dateien"],
    "{dirs} and {files}" : "{dirs} und {files}",
    "_including %n hidden_::_including %n hidden_" : ["Einschließlich %n versteckten","Einschließlich %n versteckten"],
    "You don’t have permission to upload or create files here" : "Sie haben keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
    "_Uploading %n file_::_Uploading %n files_" : ["%n Datei wird hoch geladen","%n Dateien werden hoch geladen"],
    "New" : "Neu",
    "\"{name}\" is an invalid file name." : "„{name}“ ist kein gültiger Dateiname.",
    "File name cannot be empty." : "Der Dateiname darf nicht leer sein.",
    "\"{name}\" has a forbidden file type/extension." : "\"{name}\" hat einen verbotener Dateityp bzw. Erweiterung.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Der Speicher von {owner} ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ihr Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Der Speicher von {owner} ist beinahe voll ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ihr Speicher ist fast voll ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["stimmt mit '{filter}' überein","stimmen mit '{filter}' überein"],
    "Path" : "Pfad",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favorisiert",
    "Favorite" : "Favorit",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Privater Link: Nur Personen, die Zugriff auf diese Datei/Ordner haben, können dies nutzen. Nutzen Sie dies als permanenten Link für sich selbst oder um andere auf bestimmte Dateien innerhalb der Freigaben hinzuweisen.",
    "Folder" : "Ordner",
    "New folder" : "Neuer Ordner",
    "{newname} already exists" : "{newname} existiert bereits",
    "Upload" : "Hochladen",
    "An error occurred while trying to update the tags" : "Es ist ein Fehler beim Aktualisieren der Tags aufgetreten",
    "A new file or folder has been <strong>created</strong>" : "Eine neue Datei oder ein neuer Ordner wurde <strong>erstellt</strong>",
    "A file or folder has been <strong>changed</strong>" : "Eine Datei oder ein Ordner wurde <strong>geändert</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Benachrichtigungen über Neues und Änderungen auf Ihre <strong>favorisierten Dateien</strong> beschränken <em>(nur im Stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Eine Datei oder ein Ordner wurde <strong>gelöscht</strong>",
    "A file or folder has been <strong>restored</strong>" : "Eine Datei oder ein Ordner wurde <strong>wiederhergestellt</strong>",
    "You created %1$s" : "Sie haben %1$s erstellt",
    "%2$s created %1$s" : "%2$s hat %1$s erstellt",
    "%1$s was created in a public folder" : "%1$s wurde in einem öffentlichen Ordner erstellt",
    "You changed %1$s" : "Sie haben %1$s geändert",
    "%2$s changed %1$s" : "%2$s hat %1$s geändert",
    "You deleted %1$s" : "Sie haben %1$s gelöscht",
    "%2$s deleted %1$s" : "%2$s hat %1$s gelöscht",
    "You restored %1$s" : "Sie haben %1$s wiederhergestellt",
    "%2$s restored %1$s" : "%2$s wiederhergestellt %1$s",
    "Changed by %2$s" : "Geändert von %2$s",
    "Deleted by %2$s" : "Gelöscht durch %2$s",
    "Restored by %2$s" : "Wiederhergestellt durch %2$s",
    "Upload (max. %s)" : "Hochladen (max. %s)",
    "File handling" : "Dateibehandlung",
    "Maximum upload size" : "Maximale Upload-Größe",
    "max. possible: " : "maximal möglich:",
    "Save" : "Speichern",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Bei PHP-FPM kann es 5 Minuten dauern, bis Änderungen angewendet sind.",
    "Missing permissions to edit from here." : "Fehlende Berechtigungen um von hier aus zu bearbeiten.",
    "Settings" : "Einstellungen",
    "Show hidden files" : "Versteckte Dateien anzeigen",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Benutzen Sie diese Adresse, um <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">über WebDAV auf Ihre Dateien zuzugreifen</a>",
    "No files in here" : "Keine Dateien vorhanden",
    "Upload some content or sync with your devices!" : "Laden Sie Inhalte hoch oder synchronisieren Sie mit Ihren Geräten!",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Select all" : "Alle auswählen",
    "Upload too large" : "Der Upload ist zu groß",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Die Datei überschreitet die Maximalgröße für Uploads auf diesem Server.",
    "No favorites" : "Keine Favoriten",
    "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die Sie als Favoriten kennzeichnen, werden hier erscheinen",
    "Text file" : "Textdatei",
    "New text file.txt" : "Neue Textdatei file.txt"
},
"nplurals=2; plural=(n != 1);");
